@@ -19,7 +19,7 @@ did_save_sample <- function(
   df_save <- data.table::setnames(df_save, old = c("group", "time", "S_g_XX", "switchers_tag_XX"), new = c(Gn, Tn, "did_sample", "did_effect")) 
   df_save$did_sample <- ifelse(df_save$did_sample == 0, -1, df_save$did_sample)
   df_save$did_sample <- ifelse(is.na(df_save$did_sample), 0, df_save$did_sample)
-  df_save$did_sample <- factor(df_save$did_sample, levels = c(0,1,-1), labels = c("Control", "Switcher-in", "Switchers-out"))
+  df_save$did_sample <- factor(df_save$did_sample, levels = c(0,1,-1), labels = c("Control", "Switcher-in", "Switcher-out"))
   })
 	# Return dataset to be merged to main data
   return(df_save)
